;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

;old-cus-dep-hash: #s(hash-table test equal size 10 data ("/home/nk/pkg-build/test/xemacs-packages/viper/viper-macs.el" ((viper-repeat-from-history-key . "viper-macs")) "/home/nk/pkg-build/test/xemacs-packages/viper/viper-keym.el" ((viper-ESC-key . "viper-keym") (viper-quoted-insert-key . "viper-keym") (viper-toggle-key . "viper-keym") (viper-want-ctl-h-help . "viper-keym") (viper-no-multiple-ESC . "viper-keym") (viper-want-emacs-keys-in-vi . "viper-keym") (viper-want-emacs-keys-in-insert . "viper-keym")) "/home/nk/pkg-build/test/xemacs-packages/viper/viper-init.el" ((viper-load-hook . "viper-init") (viper-emacs-state-hook . "viper-init") (viper-replace-state-hook . "viper-init") (viper-insert-state-hook . "viper-init") (viper-vi-state-hook . "viper-init") (viper-hooks . "viper-init") (viper-vi-style-in-minibuffer . "viper-init") (viper-change-notification-threshold . "viper-init") (viper-tags-file-name . "viper-init") (viper-spell-function . "viper-init") (viper-minibuffer-vi . "viper-init") (viper-minibuffer-insert . "viper-init") (viper-minibuffer-emacs . "viper-init") (viper-replace-overlay . "viper-init") (viper-search . "viper-init") (viper-highlighting . "viper-init") (viper-related-files-and-buffers-ring . "viper-init") (viper-search-wrap-around-t . "viper-init") (viper-buffer-search-char . "viper-init") (viper-delete-backwards-in-replace . "viper-init") (viper-ESC-moves-cursor-back . "viper-init") (viper-ex-style-editing . "viper-init") (viper-ex-style-motion . "viper-init") (viper-parse-sexp-ignore-comments . "viper-init") (viper-re-replace . "viper-init") (viper-re-query-replace . "viper-init") (viper-search-scroll-threshold . "viper-init") (viper-re-search . "viper-init") (viper-case-fold-search . "viper-init") (viper-quote-string . "viper-init") (viper-search . "viper-init") (viper-keep-point-on-repeat . "viper-init") (viper-shift-width . "viper-init") (viper-electric-mode . "viper-init") (viper-auto-indent . "viper-init") (viper-translate-all-ESC-keysequences . "viper-init") (viper-ESC-keyseq-timeout . "viper-init") (viper-fast-keyseq-timeout . "viper-init") (viper-command-ring-size . "viper-init") (viper-insertion-ring-size . "viper-init") (viper-read-buffer-function . "viper-init") (viper-use-replace-region-delimiters . "viper-init") (viper-replace-region-start-delimiter . "viper-init") (viper-replace-region-end-delimiter . "viper-init") (viper-emacs-state-cursor-color . "viper-init") (viper-insert-state-cursor-color . "viper-init") (viper-replace-overlay-cursor-color . "viper-init") (viper-allow-multiline-replace-regions . "viper-init") (viper-keep-point-on-undo . "viper-init") (viper-force-faces . "viper-init") (viper-suppress-input-method-change-message . "viper-init") (viper-vms-os-p . "viper-init") (viper-ms-style-os-p . "viper-init")) "/home/nk/pkg-build/test/xemacs-packages/viper/viper-cmd.el" ((viper-smart-suffix-list . "viper-cmd")) "/home/nk/pkg-build/test/xemacs-packages/viper/viper-util.el" ((viper-syntax-preference . "viper-util")) "/home/nk/pkg-build/test/xemacs-packages/viper/_pkg.el" nil "/home/nk/pkg-build/test/xemacs-packages/viper/viper.el" ((viper-major-mode-modifier-list . "viper") (viper-insert-state-mode-list . "viper") (viper-emacs-state-mode-list . "viper") (viper-vi-state-mode-list . "viper") (viper-mode . "viper") (viper-always . "viper") (viper-misc . "viper") (viper . "viper")) "/home/nk/pkg-build/test/xemacs-packages/viper/auto-autoloads.el" nil "/home/nk/pkg-build/test/xemacs-packages/viper/viper-mous.el" ((viper-mouse-insert-key . "viper-mous") (viper-mouse-search-key . "viper-mous") (viper-multiclick-timeout . "viper-mous") (viper-surrounding-word-function . "viper-mous") (viper-mouse . "viper-mous")) "/home/nk/pkg-build/test/xemacs-packages/viper/viper-ex.el" ((ex-cycle-through-non-files . "viper-ex") (ex-cycle-other-window . "viper-ex") (viper-glob-function . "viper-ex") (ex-compile-command . "viper-ex") (ex-unix-type-shell-options . "viper-ex") (ex-unix-type-shell . "viper-ex") (viper-ex . "viper-ex"))))
(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'viper '("viper-ex" "viper-init" "viper-keym" "viper-macs" "viper-mous" "viper-util" "viper"))
(custom-add-loads 'viper-hooks '("viper-init"))
(custom-add-loads 'viper-mouse '("viper-mous"))
(custom-add-loads 'viper-search '("viper-init"))
(custom-add-loads 'emulations '("viper"))
(custom-add-loads 'viper-misc '("viper-cmd" "viper-init" "viper"))
(custom-add-loads 'viper-ex '("viper-ex"))
(custom-add-loads 'viper-highlighting '("viper-init"))

;;; custom-load.el ends here
